@@ -7,7 +7,7 @@ from datetime import datetime, timezone
 from typing import Dict
 
 from tauk.context.test_case import TestCase
-from tauk.enums import TestStatus
+from tauk.enums import TestStatus, AutomationTypes
 from tauk.tauk_webdriver import Tauk
 
 logger = logging.getLogger('tauk')
@@ -45,12 +45,13 @@ class TaukListener(unittest.TestResult):
         self.test_filename = caller_filename.replace(f'{os.getcwd()}{os.sep}', '')
         test_method_name = test.id().split('.')[-1]
 
-        self.tests[test.id()] = TestCase()
-        self.tests[test.id()].method_name = test_method_name
-        self.tests[test.id()].start_timestamp = int(datetime.now(tz=timezone.utc).timestamp() * 1000)
-        self.tests[test.id()].custom_name = test.shortDescription()
+        test_case = TestCase()
+        test_case.method_name = test_method_name
+        test_case.start_timestamp = int(datetime.now(tz=timezone.utc).timestamp() * 1000)
+        test_case.custom_name = test.shortDescription()
 
-        Tauk.get_context().test_data.add_test_case(self.test_filename, self.tests[test.id()])
+        Tauk.get_context().test_data.add_test_case(self.test_filename, test_case)
+        self.tests[test.id()] = test_case
 
         super().startTest(test)
 
@@ -62,8 +63,12 @@ class TaukListener(unittest.TestResult):
 
         logger.info(f'# Test Stopped [{test.id()}] ---')
         try:
-            self.tests[test.id()].end_timestamp = int(datetime.now(tz=timezone.utc).timestamp() * 1000)
-            self.tests[test.id()].capture_appium_logs()
+            test_case = self.tests[test.id()]
+            test_case.end_timestamp = int(datetime.now(tz=timezone.utc).timestamp() * 1000)
+
+            if test_case.automation_type == AutomationTypes.APPIUM:
+                test_case.capture_appium_logs()
+
             ctx = Tauk.get_context()
 
             caller_filename = inspect.getfile(test.__class__)
@@ -76,15 +81,13 @@ class TaukListener(unittest.TestResult):
         super().addError(test, err)
         if self._should_observe(test):
             logger.debug(f'addError: Skipping Tauk observe for the test [{test.id()}] ---')
-
             return
 
         logger.info(f'# Test Errored [{test.id()}] ---')
-        self.tests[test.id()].status = TestStatus.FAILED
-
-        exctype, value, tb = err
-        traceback.print_exception(exctype, value, tb)
-        self.tests[test.id()].capture_error(self.test_filename, err)
+        test_case = self.tests[test.id()]
+        traceback.print_exception(*err)
+        test_func = getattr(test, test_case.method_name)
+        test_case.capture_failure_data(self.test_filename, err, test_func)
 
     def addFailure(self, test: unittest.case.TestCase, err: tuple) -> None:
         super().addFailure(test, err)
@@ -93,11 +96,10 @@ class TaukListener(unittest.TestResult):
             return
 
         logger.info(f'# Test Failed [{test.id()}] ---')
-        self.tests[test.id()].status = TestStatus.FAILED
-
-        exctype, value, tb = err
-        traceback.print_exception(exctype, value, tb)
-        self.tests[test.id()].capture_error(self.test_filename, err)
+        test_case = self.tests[test.id()]
+        traceback.print_exception(*err)
+        test_func = getattr(test, test_case.method_name)
+        test_case.capture_failure_data(self.test_filename, err, test_func)
 
     def addSuccess(self, test: unittest.case.TestCase) -> None:
         super().addSuccess(test)
@@ -106,7 +108,7 @@ class TaukListener(unittest.TestResult):
             return
 
         logger.info(f'# Test Passed [{test.id()}] ---')
-        self.tests[test.id()].status = TestStatus.PASSED
+        self.tests[test.id()].capture_success_data()
 
     def addSkip(self, test: unittest.case.TestCase, reason: str) -> None:
         super().addSkip(test, reason)
